@@ -2,5 +2,5 @@ from django.apps import AppConfig as DjangoAppConfig
 
 
 class AppConfig(DjangoAppConfig):
-    default_auto_field = 'django.db.models.BigAutoField'
-    name = 'newsflash.web.app'
+    default_auto_field = "django.db.models.BigAutoField"
+    name = "newsflash.web.app"
