@@ -1,13 +1,12 @@
-from typing import Type
 from django.urls import path
-from . import views
 from newsflash import App
+from . import views
 
 
 urlpatterns = []
 
 
-def set_urlpatterns(app: Type[App]) -> None:
+def set_urlpatterns(app: App) -> None:
     global urlpatterns
 
     urlpatterns = [
