@@ -1,27 +1,28 @@
-from .text import Title, Paragraph, Notifications
-from .layout import Rows, Columns, FlexRows, FlexColumns
+from .text import Title, SubTitle, SubSubTitle, Paragraph, Notifications
+from .layout import Rows, Columns, FlexRows, FlexColumns, Space
 from .control import Button, EnumSelect, ListSelect
-# from .chart import BarChart, LineChart
+from .chart import BarChart, LineChart, HistChart
 
 
 __all__ = [
     # Text
     "Title",
+    "SubTitle",
+    "SubSubTitle",
     "Paragraph",
     "Notifications",
-    
     # Layout
     "Rows",
     "Columns",
     "FlexRows",
     "FlexColumns",
-
+    "Space",
     # Control
     "Button",
     "EnumSelect",
     "ListSelect",
-
     # Charts
-    # "BarChart",
-    # "LineChart",
-]
\ No newline at end of file
+    "BarChart",
+    "LineChart",
+    "HistChart",
+]
