@@ -7,6 +7,8 @@ from pydantic import BaseModel
 
 T = TypeVar("T", bound="Widget")
 
+widget_registry: dict[str, "Widget"] = {}
+
 
 class Widget(BaseModel):
     template_name: str = ""
@@ -15,6 +17,7 @@ class Widget(BaseModel):
     height_in_px: float = 0.0
     span: int = 1
     swap_oob: bool = False
+    _cancel_update: bool = False
 
     class Config:
         validate_assignment = True
@@ -23,6 +26,18 @@ class Widget(BaseModel):
         width: float
         height: float
 
+    # TODO: The following method doesn't seem to work well with pydantic
+    # def __init_subclass__(cls):
+    #     try:
+    #         widget = cls()
+    #         if widget.id is not None:
+    #             widget_registry[widget.id] = widget
+    #     except ValidationError as err:
+    #         pass
+
+    def cancel_update(self) -> None:
+        self._cancel_update = True
+
     def _build(self, request: HttpRequest) -> Context: ...
 
     def render(self, request: HttpRequest) -> str:
@@ -35,3 +50,15 @@ class Widget(BaseModel):
     def update_dimensions(self, width_in_px: float, height_in_px: float) -> None:
         self.width_in_px = width_in_px
         self.height_in_px = height_in_px
+
+
+class ChartWidget(Widget): ...
+
+
+class ControlWidget(Widget): ...
+
+
+class TextWidget(Widget): ...
+
+
+class LayoutWidget(Widget): ...
