@@ -1,5 +1,4 @@
 from ..base import Widget
 
 
-class Chart(Widget):
-    ...
+class Chart(Widget): ...
