@@ -2,8 +2,9 @@ from django.http import HttpRequest
 
 from pydantic import BaseModel
 
-from .base import Control
-from newsflash.callback import Callback, construct_callback
+from ..base import ControlWidget
+from newsflash.callback.builder import construct_callback
+from newsflash.callback.models import Callback
 
 
 class ButtonContext(BaseModel):
@@ -12,17 +13,14 @@ class ButtonContext(BaseModel):
     callback: Callback | None
 
 
-class Button(Control):
+class Button(ControlWidget):
     template_name: str = "control/button"
     text: str
 
     def _build(self, request: HttpRequest) -> ButtonContext:
         assert self.id is not None
 
-        if "on_click" in self.__class__.__dict__:
-            callback = construct_callback(self.__class__.on_click, "click", "click")
-        else:
-            callback = None
+        callback = construct_callback(self.__class__.on_click, "click", "click")
 
         return ButtonContext(
             id=self.id,
@@ -30,5 +28,4 @@ class Button(Control):
             callback=callback,
         )
 
-    def on_click(self, *args, **kwargs) -> None:
-        ...
+    def on_click(self, *args, **kwargs) -> None: ...
