@@ -1,11 +1,7 @@
 from .columns import Columns
 from .rows import Rows
 from .flex import FlexColumns, FlexRows
+from .space import Space
 
 
-__all__ = [
-    "Columns",
-    "Rows",
-    "FlexColumns",
-    "FlexRows",
-]
+__all__ = ["Columns", "Rows", "FlexColumns", "FlexRows", "Space"]
