@@ -1,4 +1,5 @@
 from .base import Layout
+from ..base import Widget
 
 from pydantic import BaseModel
 from django.http import HttpRequest
@@ -28,3 +29,7 @@ class FlexColumns(Flex):
 
 class FlexRows(Flex):
     direction: str = "col"
+
+
+def build_rows(*children: Widget, span: int = 1) -> FlexRows:
+    return FlexRows(children=list(children), span=span)
