@@ -1,10 +1,12 @@
-from .title import Title
+from .title import Title, SubTitle, SubSubTitle
 from .paragraph import Paragraph
 from .notifications import Notifications
 
 
 __all__ = [
     "Title",
+    "SubTitle",
+    "SubSubTitle",
     "Paragraph",
     "Notifications",
 ]
