@@ -1,7 +1,7 @@
 from django.http import HttpRequest
 
 from pydantic import BaseModel
-from .base import Text
+from ..base import TextWidget
 
 
 class Notification(BaseModel):
@@ -13,11 +13,11 @@ class NotificationsContext(BaseModel):
     notifications: list[Notification]
 
 
-class Notifications(Text):
+class Notifications(TextWidget):
     template_name: str = "text/notification"
     notifications: list[Notification] = []
 
-    def push(self, text: str, duration_in_ms: int = 2000) -> None:
+    def push(self, text: str, duration_in_ms: int = 5000) -> None:
         self.notifications.append(
             Notification(
                 text=text,
@@ -26,6 +26,4 @@ class Notifications(Text):
         )
 
     def _build(self, request: HttpRequest) -> NotificationsContext:
-        return NotificationsContext(
-            notifications=self.notifications
-        )
+        return NotificationsContext(notifications=self.notifications)
