@@ -1,6 +1,6 @@
 from django.http import HttpRequest
 
-from .base import Text
+from ..base import TextWidget
 from pydantic import BaseModel
 
 
@@ -8,7 +8,7 @@ class ParagraphContext(BaseModel):
     text: str
 
 
-class Paragraph(Text):
+class Paragraph(TextWidget):
     template_name: str = "text/paragraph"
     text: str
 
